.. Copyright 2013-2023 Reahl Software Services (Pty) Ltd. All rights reserved.

Tofu -- Test Fixtures and other handy testing utilities (reahl.tofu)
--------------------------------------------------------------------

Tofu's docs have moved:
- :doc:`Introduction <../tofu/introduction>`
- :doc:`API reference <../tofu/index>`
